@@ -26,6 +26,14 @@ def set(txt:str):
     subprocess.run(f'start /wait {dst.name}',shell=True)
     dst.unlink()
 
+def set2(txt:str):
+    qr = pyqrcode.create(txt)
+    print(qr.terminal())
+    # dst = Path('set.png')
+    # qr.png(dst,scale=10)
+    # subprocess.run(f'start /wait {dst.name}',shell=True)
+    # dst.unlink()
+
 def main():
     p = argparse.ArgumentParser()
     sub_p = p.add_subparsers(dest='cmd',required=True)
@@ -37,7 +45,7 @@ def main():
     if args.cmd == 'get':
         get()
     elif args.cmd == 'set':
-        set(args.text)
+        set2(args.text)
     else:
         print(f'unhandled [{args.cmd}]')
 
